IDIFF :: improving 2D diffraction patterns
------------------------------------------

* IDIFF improves 2D diffractograms by removing background and noise.

Quick start
-----------

* TODO

Documentation, help and examples
--------------------------------

* TODO

Versions of EDIFF
-----------------

* Version 0.0.1 = just draft
